// src/index.ts
import remarkExpressiveCode, { createRenderer } from "remark-expressive-code";
export * from "remark-expressive-code";
function astroExpressiveCode(options = {}) {
  const integration = {
    name: "astro-expressive-code",
    hooks: {
      "astro:config:setup": async (args) => {
        const { config, updateConfig, injectScript } = args;
        const { customCreateRenderer } = options ?? {};
        const ownPosition = config.integrations.findIndex((integration2) => integration2.name === "astro-expressive-code");
        const mdxPosition = config.integrations.findIndex((integration2) => integration2.name === "@astrojs/mdx");
        if (ownPosition > -1 && mdxPosition > -1 && mdxPosition < ownPosition) {
          throw new Error(
            `Incorrect integration order: To allow code blocks on MDX pages to use
						astro-expressive-code, please move astroExpressiveCode() before mdx()
						in the "integrations" array of your Astro config file.`.replace(/\s+/g, " ")
          );
        }
        const renderer = await (customCreateRenderer ?? createRenderer)(options);
        const jsModules = /* @__PURE__ */ new Set();
        renderer.jsModules.forEach((jsModule) => jsModules.add(jsModule));
        renderer.jsModules = [];
        const remarkExpressiveCodeOptions = {
          ...options,
          customCreateRenderer: () => renderer
        };
        updateConfig({
          markdown: {
            syntaxHighlight: false,
            remarkPlugins: [[remarkExpressiveCode, remarkExpressiveCodeOptions]]
          }
        });
        jsModules.forEach((moduleCode) => injectScript("page", moduleCode));
      }
    }
  };
  return integration;
}
var src_default = astroExpressiveCode;
export {
  astroExpressiveCode,
  src_default as default
};
//# sourceMappingURL=index.js.map